@@ -12,3 +12,9 @@ def get_conn():
         # Apparently you need to enable this pragma _per connection_
         _conn.cursor().execute("PRAGMA foreign_keys = ON;")
     return _conn
+
+
+def run_sql(*args, **kwargs):
+    cursor = get_conn().cursor()
+    results = cursor.execute(*args, **kwargs)
+    return list(results)
